# Python API

::: bioclip.TreeOfLifeClassifier
    options:
      members:
      - predict
      - get_label_data
      - create_taxa_filter
      - apply_filter
      show_root_heading: true
      show_source: true

::: bioclip.Rank
    options:
      show_root_heading: true
      show_bases: false
-  `KINGDOM`
-  `PHYLUM`
-  `CLASS`
-  `ORDER`
-  `FAMILY`
-  `GENUS`
-  `SPECIES`

::: bioclip.CustomLabelsClassifier
    options:
      members:
      - predict
      show_root_heading: true
      show_source: true

::: bioclip.CustomLabelsBinningClassifier
    options:
      members:
      - predict
      show_root_heading: true
      show_source: true

::: bioclip.predict.BaseClassifier
    options:
      show_root_heading: true
